ranksSet(node)
ranksStats(node)
ranksClear(node)ranksStats returns a data frame with columns:ranksSet creates a monitor that starts building running histograms to represent
the rank of each component of node.
An amount of storage proportional to the square of the number of components of node is allocated.
Even for large numbers of components this can require less storage than calculating the ranks
explicitly in the model specification and storing their samples, and it is also much quicker.
ranksStats displays summarises of the distribution of the ranks of each component of node.
ranksClear removes the monitor calculating running histograms for node.BRugs, help.WinBUGS